===================================
wslwinreg for Cygwin, MSYS2 and WSL
===================================

|PyPi| |License| |Travis| |Docs| |Versions|

The ``wslwinreg`` module is a drop in replacement for winreg for systems
running under Cygwin, MSYS2, or Windows Subsystem for Linux.

* Documentation is found at https://wslwinreg.readthedocs.io

* Doxygen generated documentation is found at https://wslwinreg.readthedocs.io/en/latest/doxygen

* Python Packing Index (PyPI): https://pypi.python.org/pypi/wslwinreg

* Source code and issue tracker: https://github.com/burgerbecky/wslwinreg

Compatibility
-------------

* Python 2.7.1 or higher
* Python 3.4 or higher

Installation
------------

Type in ``pip install -U wslwinreg``. Some platforms may require the ``sudo``
prefix.

Bugs
----

If you find a bug, issue or have a feature request, please submit a bug report
by emailing becky@burgerbecky.com and mention python version, integer
size (32 bit or 64 bit) and what platform was used (Windows / MSYS2 / Cygwin /
Windows Subsystem for Linux).

.. |PyPi| image:: https://img.shields.io/pypi/v/wslwinreg.svg
    :target: https://pypi.org/project/wslwinreg/
    :alt: Pypi Version
.. |License| image:: https://img.shields.io/pypi/l/wslwinreg.svg
    :target: https://github.com/burgerbecky/wslwinreg/blob/master/LICENSE.txt
    :alt: License
.. |Travis| image:: https://img.shields.io/travis/burgerbecky/wslwinreg.svg
    :target: https://travis-ci.org/burgerbecky/wslwinreg
    :alt: Travis Status
.. |Docs| image:: https://img.shields.io/readthedocs/wslwinreg.svg
    :target: http://wslwinreg.readthedocs.io
    :alt: Documentation Status
.. |Versions| image:: https://img.shields.io/pypi/pyversions/wslwinreg.svg
    :alt: Supported Python versions
